import {  RouteRecordRaw, RouterView } from "vue-router";
import NotFound from "@/views/404/index.vue"
interface MenuItem {
  uuid: string;
  path: string;
  label: string;
  icon: string;
  menuCode: string;
  adaptability: string;
  component: string;
  sort: number;
  status: string;
  query: string;
  parentId?: string;
  children?: MenuItem[];
}
function getComponent(componentPath: string) {
  // 处理view-router特殊路由
  if (componentPath === 'view-router') {
    return RouterView
  }
  
  // 动态导入组件，添加错误处理
  return () => {
    try {
      // 尝试动态导入组件
      const componentPromise = import(`../views/${componentPath}`)
      
      // 成功加载则返回组件
      return componentPromise.catch(() => {
        console.error(`组件加载失败: @/views/${componentPath}, 回退到404页面`)
        return NotFound
      })
      
    } catch (error) {
      console.error('动态导入组件时发生错误:', error)
      return NotFound
    }
  }
}
export function generateRoutes(menuList: MenuItem[]): RouteRecordRaw[] {
  return menuList.map((menu) => {
    const route: RouteRecordRaw = {
      path: menu.path,
      name: menu.path.toUpperCase(), //路径转大写
      meta: {
        ...(menu.query ? JSON.parse(menu.query) : {})
      },
      component: getComponent(menu.component),
      children:[]
    };

    if (menu.children && menu.children.length > 0) {
      route.children = generateRoutes(menu.children);
    }

    return route;
  });
}
